# Generated by Django 6.0.1 on 2026-02-04 09:42

import content_studio.contrib.password_reset.models
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="PasswordResetCode",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "email",
                    models.EmailField(
                        editable=False, max_length=255, verbose_name="Email address"
                    ),
                ),
                (
                    "code",
                    models.CharField(
                        default=content_studio.contrib.password_reset.models.generate_code,
                        editable=False,
                        max_length=6,
                        verbose_name="Code",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(auto_now_add=True, verbose_name="Created at"),
                ),
            ],
            options={
                "verbose_name": "Password reset code",
                "verbose_name_plural": "Password reset codes",
                "db_table": "dcs_password_reset_code",
            },
        ),
    ]
