from rest_framework import serializers


class PasswordResetRequestSerializer(serializers.Serializer):
    email = serializers.EmailField()


class CodeValidationSerializer(serializers.Serializer):
    code = serializers.CharField(max_length=6)


class PasswordResetSubmissionSerializer(serializers.Serializer):
    code = serializers.CharField(max_length=6)
    email = serializers.EmailField()
    password = serializers.CharField(min_length=8)
