{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link rel="icon" href={% static 'content_studio/icon.png' %}>
    <title>Django Content Studio</title>
    <script>
        window.DCS_STATIC_PREFIX = "{% static '' %}content_studio/";
        window.DCS_BASENAME = "{% url 'content_studio_web' %}";
    </script>
    <script type="module" crossorigin src="{% static 'content_studio/assets/index.js' %}?v={{ version }}"></script>
    <link rel="stylesheet" crossorigin href="{% static 'content_studio/assets/index.css' %}?v={{ version }}">
    <link rel="stylesheet" crossorigin href="{% static 'content_studio/icons/pi/style.css' %}?v={{ version }}">
</head>
<body>
    <div id="root"></div>
</body>
</html>